==> rkt_1.29.0+dfsg.orig.tar.xz: rkt-1.29.0/Documentation/integrations.md <==
# Integrations
This document tracks projects that integrate with rkt. [Join the community](https://github.com/rkt/rkt/), and help us keep the list up-to-date.

## Projects 
[Kubernetes](https://kubernetes.io/docs/getting-started-guides/rkt/): a enterprise grade container orchestration solution. Kubernetes offers rkt support as an alternative to the standard install.

[Mesos](http://mesos.apache.org/blog/mesos-1-0-0-released/): Apache Mesos abstracts CPU, memory, storage, and other compute resources away from machines (physical or virtual), enabling fault-tolerant and elastic distributed systems to easily be built and run effectively.

[Nomad](https://www.nomadproject.io/docs/drivers/rkt.html): a container orchestration platform focused on ease of use. Nomad supports rkt through the rkt driver.

[dgr](https://github.com/blablacar/dgr): a container build and runtime tool, preferring convention over configuration.

[Mulled](https://github.com/BioContainers/mulled): a tool for generating minimal container images.

[Quay.io](https://quay.io/): an enterprise ready container registry. Quay hosts rkt images.

[SELinux](https://coreos.com/rkt/docs/latest/selinux.html): an access control and security toolkit for containers.

[Linux](https://coreos.com/rkt/docs/latest/distributions.html): an open and extensible OS. rkt is included in the package managers on Red Hat, Ubuntu, and many other popular Linux distributions.

[cAdvisor](https://github.com/google/cadvisor): a daemon that monitors resource usage and performance for running containers.

==> rkt_1.30.0+dfsg1.orig.tar.xz: rkt-1.30.0/Documentation/integrations.md <==
# Integrations
This document tracks projects that integrate with rkt. [Join the community](https://github.com/rkt/rkt/), and help us keep the list up-to-date.

## Projects 
[Kubernetes](https://github.com/kubernetes-incubator/rktlet): an enterprise grade container orchestration solution. Kubernetes offers rkt support as an alternative to the standard install.

[Mesos](http://mesos.apache.org/blog/mesos-1-0-0-released/): Apache Mesos abstracts CPU, memory, storage, and other compute resources away from machines (physical or virtual), enabling fault-tolerant and elastic distributed systems to easily be built and run effectively.

[Nomad](https://www.nomadproject.io/docs/drivers/rkt.html): a container orchestration platform focused on ease of use. Nomad supports rkt through the rkt driver.

[dgr](https://github.com/blablacar/dgr): a container build and runtime tool, preferring convention over configuration.

[Mulled](https://github.com/BioContainers/mulled): a tool for generating minimal container images.

[Quay.io](https://quay.io/): an enterprise ready container registry. Quay hosts rkt images.

[SELinux](https://coreos.com/rkt/docs/latest/selinux.html): an access control and security toolkit for containers.

[Linux](https://coreos.com/rkt/docs/latest/distributions.html): an open and extensible OS. rkt is included in the package managers on Red Hat, Ubuntu, and many other popular Linux distributions.

[cAdvisor](https://github.com/google/cadvisor): a daemon that monitors resource usage and performance for running containers.
